.. module:: bana.OpenMaya.MTransformationMatrix

.. _openmaya_mtransformationmatrix:

OpenMaya.MTransformationMatrix
==============================

.. autosummary::
   :nosignatures:

   ~MTransformationMatrix.bnAddRotation
   ~MTransformationMatrix.bnGetRotation
   ~MTransformationMatrix.bnSetRotation
   ~MTransformationMatrix.bnAddRotationQuaternion
   ~MTransformationMatrix.bnGetRotationQuaternion
   ~MTransformationMatrix.bnSetRotationQuaternion
   ~MTransformationMatrix.bnAddScale
   ~MTransformationMatrix.bnGetScale
   ~MTransformationMatrix.bnSetScale
   ~MTransformationMatrix.bnAddShear
   ~MTransformationMatrix.bnGetShear
   ~MTransformationMatrix.bnSetShear


----

.. automethod:: MTransformationMatrix.bnAddRotation

----

.. automethod:: MTransformationMatrix.bnGetRotation

----

.. automethod:: MTransformationMatrix.bnSetRotation

----

.. automethod:: MTransformationMatrix.bnAddRotationQuaternion

----

.. automethod:: MTransformationMatrix.bnGetRotationQuaternion

----

.. automethod:: MTransformationMatrix.bnSetRotationQuaternion

----

.. automethod:: MTransformationMatrix.bnAddScale

----

.. automethod:: MTransformationMatrix.bnGetScale

----

.. automethod:: MTransformationMatrix.bnSetScale

----

.. automethod:: MTransformationMatrix.bnAddShear

----

.. automethod:: MTransformationMatrix.bnGetShear

----

.. automethod:: MTransformationMatrix.bnSetShear
